@@ -22,12 +22,20 @@ but useful for IMDbPY-based programs.
 
 # XXX: Find better names for the functions in this module.
 
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+import sys
 import difflib
 import gettext
 import re
-from cgi import escape
 from gettext import gettext as _
 
+PY2 = sys.hexversion < 0x3000000
+if PY2:
+    from cgi import escape
+else:
+    from html import escape
+
 # The modClearRefs can be used to strip names and titles references from
 # the strings in Movie and Person objects.
 from imdb import IMDb, imdbURL_character_base, imdbURL_movie_base, imdbURL_person_base
@@ -35,7 +43,6 @@ from imdb.Character import Character
 from imdb.Company import Company
 from imdb.linguistics import COUNTRY_LANG
 from imdb.Movie import Movie
-from imdb.parser.http.utils import entcharrefs
 from imdb.Person import Person
 from imdb.utils import _tagAttr, re_characterRef, re_nameRef, re_titleRef
 from imdb.utils import TAGS_TO_MODIFY
@@ -269,34 +276,6 @@ modHtmlLinksASCII = makeModCGILinks(movieTxt=_movieTxt, personTxt=_personTxt,
                                     encoding='ascii')
 
 
-everyentcharrefs = entcharrefs.copy()
-for k, v in list({'lt': '<', 'gt': '>', 'amp': '&', 'quot': '"', 'apos': '\''}.items()):
-    everyentcharrefs[k] = v
-    everyentcharrefs['#%s' % ord(v)] = v
-everyentcharrefsget = everyentcharrefs.get
-re_everyentcharrefs = re.compile('&(%s|\#160|\#\d{1,5});' % '|'.join(map(re.escape,
-                                                                         everyentcharrefs)))
-re_everyentcharrefssub = re_everyentcharrefs.sub
-
-
-def _replAllXMLRef(match):
-    """Replace the matched XML reference."""
-    ref = match.group(1)
-    value = everyentcharrefsget(ref)
-    if value is None:
-        if ref[0] == '#':
-            return chr(int(ref[1:]))
-        else:
-            return ref
-    return value
-
-
-def subXMLHTMLSGMLRefs(s):
-    """Return the given string with XML/HTML/SGML entity and char references
-    replaced."""
-    return re_everyentcharrefssub(_replAllXMLRef, s)
-
-
 def sortedSeasons(m):
     """Return a sorted list of seasons of the given series."""
     seasons = list(m.get('episodes', {}).keys())
@@ -549,7 +528,7 @@ def parseXML(xml):
 
 
 _re_akas_lang = re.compile('(?:[(])([a-zA-Z]+?)(?: title[)])')
-_re_akas_country = re.compile('\(.*?\)')
+_re_akas_country = re.compile(r'\(.*?\)')
 
 
 # akasLanguages, sortAKAsBySimilarity and getAKAsInLanguage code
@@ -626,3 +605,25 @@ def getAKAsInLanguage(movie, lang, _searchedTitle=None):
         scores.sort(reverse=True)
         akas = [x[1] for x in scores]
     return akas
+
+
+def resizeImage(image, width=None, height=None, crop=None):
+    """Return resized and cropped image url."""
+
+    regexString = r'https://m.media-amazon.com/images/\w/\w+'
+
+    resultImage = re.findall(regexString, image)[0]
+    resultImage += '@._V1_'
+
+    if width:
+        resultImage += 'SX%s_' % width
+    if height:
+        resultImage += 'SY%s_' % height
+
+    if crop:
+        cropVals = ','.join(crop)
+        resultImage += 'CR%s_' % cropVals
+
+    resultImage += '.jpg'
+
+    return resultImage
